@@ -13,7 +13,7 @@ from typing import List, Optional
 from pydantic import BaseModel
 
 from .. import units
-from ..database import CurrentConditions
+from ..database import CurrentConditions, HourlyForecast
 from . import BaseStation, WeatherProvider
 
 logger = logging.getLogger(__name__)
@@ -53,7 +53,7 @@ class API_Conditions(BaseModel):
     nearestStormBearing: Optional[float] = None
 
 
-class API_Forecast(BaseModel):
+class API_DailyWeather(BaseModel):
     time: datetime
     summary: str
     icon: Optional[str] = None
@@ -110,7 +110,7 @@ class API_Hourly(BaseModel):
 class API_Daily(BaseModel):
     summary: str
     icon: Optional[str] = None
-    data: List[API_Forecast] = []
+    data: List[API_DailyWeather] = []
 
 
 class API_Flags(BaseModel):
@@ -146,6 +146,8 @@ class Station(BaseStation):
         # generate a station ID for database entries
         self.station_id = f"{latitude},{longitude}"
 
+        self._cached = None
+
     @property
     def provider(self) -> WeatherProvider:
         """Return the provider name for this WeatherStation."""
@@ -153,12 +155,12 @@ class Station(BaseStation):
 
     @property
     def current_conditions(self) -> CurrentConditions:
-        weather = self.get_current_weather()
+        self._cached = self.get_current_weather()
 
-        if weather is None:
+        if self._cached is None:
             return None
 
-        conditions = weather.currently
+        conditions = self._cached.currently
 
         # convert pressure from hPa to inHg
 
@@ -180,6 +182,40 @@ class Station(BaseStation):
             remarks=conditions.summary,
         )
 
+    @property
+    def hourly_forecast(self) -> List[HourlyForecast]:
+        """Return the hourly forecast for this WeatherStation."""
+        self._cached = self.get_current_weather()
+
+        if self._cached is None:
+            return None
+
+        hourly = self._cached.hourly
+        origin_time = self._cached.currently.time
+
+        return [
+            HourlyForecast(
+                timestamp=hour.time,
+                origin_time=origin_time,
+                provider=self.provider,
+                station_id=self.station_id,
+                temperature=hour.temperature,
+                feels_like=hour.apparentTemperature,
+                wind_speed=hour.windSpeed,
+                wind_gusts=hour.windGust,
+                wind_bearing=hour.windBearing,
+                humidity=hour.humidity,
+                precip=hour.precipIntensity,
+                abs_pressure=units.hPa(hour.pressure).inHg,
+                cloud_cover=hour.cloudCover * 100.0,
+                visibility=hour.visibility,
+                ozone=hour.ozone,
+                uv_index=hour.uvIndex,
+                remarks=hour.summary,
+            )
+            for hour in hourly.data
+        ]
+
     def get_current_weather(self) -> API_Weather:
         self.logger.debug("getting current weather")
 
